@@ -1,7 +1,7 @@
-"""The CanvasPlus package, version 1.3.0"""
+"""The CanvasPlus package, version 1.3.1"""
 """
 Luke-zhang-04
-CanvasPlus v1.3.0 (https://github.com/Luke-zhang-04/CanvasPlus)
+CanvasPlus v1.3.1 (https://github.com/Luke-zhang-04/CanvasPlus)
 Copyright (C) 2020 Luke Zhang
 """
 
@@ -25,20 +25,31 @@ from typing import Tuple, Union, List, Callable, Dict
 #warnings
 import warnings
 
-#errors
-from CanvasPlus._errors import *
+if __name__ != "__main__":
+    #errors
+    from CanvasPlus._errors import *
+
+    #templates
+    from CanvasPlus.templates import Template
+else:
+    #errors
+    from _errors import *
+
+    #templates
+    from templates import Template
 
 #regex
 import re
 
+#inspect
+import inspect
+
 #asyncio
 try: import asyncio
 except ImportError:
-    print("Library Asyncio not found. You have four options\n1. use python 3.7 or higher\n2. install asyncio with pip (pip install asyncio)\n3. Download CanvasPlus version 1.2.2 which does not use asyncio, but loose async features\n4. Use the programs default mechanism which imports an older version of asyncio")
-    print("importing The asyncio package, tracking PEP 3156")
-    import CanvasPlus.asyncio_old as asyncio
+    print("Library Asyncio not found. You have four options\n1. use python 3.7 or higher\n2. install asyncio with pip (pip install asyncio)\n3. Download CanvasPlus version 1.2.2 which does not use asyncio, but loose async features\n4. Download the asyncio library from GitHub https://www.google.com/search?client=firefox-b-d&q=asyncio+github")
 
-_canvasPlusVersion = "v1.3.0"
+_canvasPlusVersion = "v1.3.1"
 
 print("This is CanvasPlus %s" % _canvasPlusVersion)
 
@@ -569,6 +580,21 @@ class CanvasPlus(Canvas, WidgetWindows, Transformations, AsyncTransformations):
                 )
             return bindings
 
+    def render_template(self, template: Template, *args, **kwargs):
+        """Renders a template from the template class"""
+        coords = args if len(template.coords) == 0 else template.coords
+
+        properties = template.properties
+        for i in kwargs:
+            properties[i] = kwargs[i]
+        
+        shape = self._create(template.type, coords, properties)
+
+        if template.onRender:
+            template.onRender(shape)
+
+        return shape
+
 
 def _test():
     #Imports
