@@ -1,7 +1,7 @@
-"""The CanvasPlus package, version 1.3.0 for Python 3.0-3.4"""
+"""The CanvasPlus package, version 1.3.1 for Python 3.0-3.4"""
 """
 Luke-zhang-04
-CanvasPlus v1.3.0 (https://github.com/Luke-zhang-04/CanvasPlus)
+CanvasPlus v1.3.1 (https://github.com/Luke-zhang-04/CanvasPlus)
 Copyright (C) 2020 Luke Zhang
 """
 
@@ -20,8 +20,18 @@ import cmath, math
 #warnings
 import warnings
 
-#errors
-from CanvasPlus._errors import *
+if __name__ != "__main__":
+    #errors
+    from CanvasPlus._errors import *
+
+    #templates
+    from CanvasPlus.templates import Template
+else:
+    #errors
+    from _errors import *
+
+    #templates
+    from templates import Template
 
 #regex
 import re
@@ -29,11 +39,9 @@ import re
 #asyncio
 try: import asyncio
 except ImportError:
-    print("Library Asyncio not found. You have four options\n1. use python 3.7 or higher\n2. install asyncio with pip (pip install asyncio)\n3. Download CanvasPlus version 1.2.2 which does not use asyncio, but loose async features\n4. Use the programs default mechanism which imports an older version of asyncio")
-    print("importing The asyncio package, tracking PEP 3156")
-    import CanvasPlus.asyncio_old as asyncio
+    print("Library Asyncio not found. You have four options\n1. use python 3.7 or higher\n2. install asyncio with pip (pip install asyncio)\n3. Download CanvasPlus version 1.2.2 which does not use asyncio, but loose async features\n4. Download the asyncio library from GitHub https://www.google.com/search?client=firefox-b-d&q=asyncio+github")
 
-_canvasPlusVersion = "v1.3.0"
+_canvasPlusVersion = "v1.3.1"
 
 print("This is CanvasPlus %s" % _canvasPlusVersion)
 
